# BuildAnalysisResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**base_image_analysis** | [**BuildAnalysisResponseBaseImageAnalysis**](BuildAnalysisResponseBaseImageAnalysis.md) |  | [optional]
**output_image_analysis** | [**BuildAnalysisResponseBaseImageAnalysis**](BuildAnalysisResponseBaseImageAnalysis.md) |  | [optional]
**buildlog_analysis** | [**BuildAnalysisResponseBaseImageAnalysis**](BuildAnalysisResponseBaseImageAnalysis.md) |  | [optional]
**buildlog_document_id** | **str** | Document identifier for the stored build log. | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

